@@ -1,6 +1,6 @@
-#ifndef lint
-static char *RCSid() { return RCSid("$Id: wmenu.c,v 1.22.2.1 2014/07/04 07:45:44 markisch Exp $"); }
-#endif
+/*
+ * $Id: wmenu.c,v 1.27.2.1 2016/09/12 17:22:56 markisch Exp $Id: wmenu.c,v 1.27.2.1 2016/09/12 17:22:56 markisch Exp $
+ */
 
 /* GNUPLOT - win/wmenu.c */
 /*[
@@ -41,14 +41,9 @@ static char *RCSid() { return RCSid("$Id: wmenu.c,v 1.22.2.1 2014/07/04 07:45:44
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
-
+#include "syscfg.h"
 #define STRICT
 #define COBJMACROS
-/* required for COMCTRL32 5.81 or later */
-#define _WIN32_IE 0x0501
 #include <windows.h>
 #include <windowsx.h>
 #include <commdlg.h>
@@ -69,7 +64,6 @@ static char *RCSid() { return RCSid("$Id: wmenu.c,v 1.22.2.1 2014/07/04 07:45:44
 #define SHELL_DIR_DIALOG
 
 INT_PTR CALLBACK InputBoxDlgProc(HWND, UINT, WPARAM, LPARAM);
-INT CALLBACK BrowseCallbackProc(HWND hwnd, UINT uMsg, LPARAM lp, LPARAM pData);
 
 /* limits */
 #define MAXSTR 255
@@ -127,6 +121,8 @@ static void TranslateMacro(char *string);
 
 #ifdef SHELL_DIR_DIALOG
 
+INT CALLBACK BrowseCallbackProc(HWND hwnd, UINT uMsg, LPARAM lp, LPARAM pData);
+
 /* This is missing in MingW 2.95 */
 #ifndef BIF_EDITBOX
 # define BIF_EDITBOX 0x0010
@@ -768,6 +764,7 @@ int i;
 RECT rect;
 char *ButtonText[BUTTONMAX];
 int ButtonIcon[BUTTONMAX];
+TBADDBITMAP bitmap = {0};
 
 	lpmw = lptw->lpmw;
 
@@ -909,7 +906,7 @@ int ButtonIcon[BUTTONMAX];
 			AppendMenu(hMenu[nMenuLevel], MF_SEPARATOR | MF_MENUBARBREAK, 0, (LPSTR)NULL);
 		}
 		else {
-			AppendMenu(hMenu[nMenuLevel], MF_STRING, lpmw->nCountMenu, (LPSTR)buf);
+			AppendMenu(hMenu[nMenuLevel],MF_STRING, lpmw->nCountMenu, (LPSTR)buf);
 			if (!(nInc = GetLine(buf,MAXSTR,menufile))) {
 				nLine += nInc;
 				wsprintf(buf, "Problem on line %d of %s\n", nLine, lpmw->szMenuName);
@@ -950,16 +947,22 @@ int ButtonIcon[BUTTONMAX];
 	if (lpmw->hToolbar == NULL)
 	    goto cleanup;
 
+	SendMessage(lpmw->hToolbar, TB_BUTTONSTRUCTSIZE, (WPARAM)sizeof(TBBUTTON), 0);
+
 	/* set size of toolbar icons */
 	/* lparam is (height<<16 + width) / default 16,15 */
-	SendMessage(lpmw->hToolbar, TB_SETBITMAPSIZE, (WPARAM)0, (LPARAM)((16<<16) + 16));
+	SendMessage(lpmw->hToolbar, TB_SETBITMAPSIZE, (WPARAM)0, MAKELPARAM(16, 16));
 	/* load standard toolbar icons: standard, history & view */
-	SendMessage(lpmw->hToolbar, TB_LOADIMAGES, (WPARAM)IDB_STD_SMALL_COLOR, (LPARAM)HINST_COMMCTRL);
-	SendMessage(lpmw->hToolbar, TB_LOADIMAGES, (WPARAM)IDB_HIST_SMALL_COLOR, (LPARAM)HINST_COMMCTRL);
-	SendMessage(lpmw->hToolbar, TB_LOADIMAGES, (WPARAM)IDB_VIEW_SMALL_COLOR, (LPARAM)HINST_COMMCTRL);
+
+	bitmap.hInst = HINST_COMMCTRL;
+	bitmap.nID = IDB_STD_SMALL_COLOR;
+	SendMessage(lpmw->hToolbar, TB_ADDBITMAP, 0, (WPARAM)&bitmap);
+	bitmap.nID = IDB_HIST_SMALL_COLOR;
+	SendMessage(lpmw->hToolbar, TB_ADDBITMAP, 0, (WPARAM)&bitmap);
+	bitmap.nID = IDB_VIEW_SMALL_COLOR;
+	SendMessage(lpmw->hToolbar, TB_ADDBITMAP, 0, (WPARAM)&bitmap);
 
 	/* create buttons */
-	SendMessage(lpmw->hToolbar, TB_BUTTONSTRUCTSIZE, (WPARAM)sizeof(TBBUTTON), 0);
 	for (i = 0; i < lpmw->nButton; i++) {
 		TBBUTTON button;
 		ZeroMemory(&button, sizeof(button));
@@ -985,10 +988,8 @@ int ButtonIcon[BUTTONMAX];
 	SetWindowPos(lptw->hWndText, (HWND)NULL, 0, lptw->ButtonHeight,
 			rect.right, rect.bottom - lptw->ButtonHeight - lptw->StatusHeight,
 			SWP_NOZORDER | SWP_NOACTIVATE);
-
 	goto cleanup;
 
-
 nomemory:
 	MessageBox(lptw->hWndParent, "Out of memory", lptw->Title, MB_ICONEXCLAMATION);
 errorcleanup:
@@ -1011,14 +1012,15 @@ cleanup:
 	if (menufile != (GFILE *)NULL)
 		Gfclose(menufile);
 	return;
-
 }
 
+
 void
 CloseMacros(LPTW lptw)
 {
 HGLOBAL hglobal;
 LPMW lpmw;
+
 	lpmw = lptw->lpmw;
 
 	hglobal = (HGLOBAL)GlobalHandle(lpmw->macro);
